==> collective.atimage.transformtoolbar-1.2.tar.gz: collective.atimage.transformtoolbar-1.2/collective/atimage/transformtoolbar/tests/test_doctest.py <==
import unittest

from zope.testing import doctestunit
from zope.component import testing
from Testing import ZopeTestCase as ztc

from Products.Five import zcml
from Products.Five import fiveconfigure
from Products.PloneTestCase import PloneTestCase as ptc
from Products.PloneTestCase.layer import PloneSite

from collective.atimage.transformmenu.tests import base

ztc.installProduct('collective.atimage.transformmenu')
ptc.setupPloneSite(products=['collective.atimage.transformmenu'])

import collective.atimage.transformmenu

class TestCase(ptc.PloneTestCase):
    class layer(PloneSite):
        @classmethod
        def setUp(cls):
            fiveconfigure.debug_mode = True
            zcml.load_config('configure.zcml',
                             collective.atimage.transformmenu)
            fiveconfigure.debug_mode = False

        @classmethod
        def tearDown(cls):
            pass


def test_suite():
    return unittest.TestSuite([

        # Unit tests
        #doctestunit.DocFileSuite(
        #    'README.txt', package='collective.atimage.transformmenu',
        #    setUp=testing.setUp, tearDown=testing.tearDown),

        #doctestunit.DocTestSuite(
        #    module='collective.atimage.transformmenu.mymodule',
        #    setUp=testing.setUp, tearDown=testing.tearDown),


        # Integration tests that use PloneTestCase
        ztc.ZopeDocFileSuite(
            'README.txt', package='collective.atimage.transformmenu',
            test_class=base.FunctionalTestCase),

        #ztc.FunctionalDocFileSuite(
        #    'browser.txt', package='collective.atimage.transformmenu',
        #    test_class=TestCase),

        ])

if __name__ == '__main__':
    unittest.main(defaultTest='test_suite')

==> collective.atimage.transformtoolbar-1.2.1.tar.gz: collective.atimage.transformtoolbar-1.2.1/collective/atimage/transformtoolbar/tests/test_doctest.py <==
import unittest

from zope.testing import doctestunit
from zope.component import testing
from Testing import ZopeTestCase as ztc

from Products.Five import zcml
from Products.Five import fiveconfigure
from Products.PloneTestCase import PloneTestCase as ptc
from Products.PloneTestCase.layer import PloneSite

from collective.atimage.transformtoolbar.tests import base

ztc.installProduct('collective.atimage.transformtoolbar')
ptc.setupPloneSite(products=['collective.atimage.transformtoolbar'])

import collective.atimage.transformtoolbar

class TestCase(ptc.PloneTestCase):
    class layer(PloneSite):
        @classmethod
        def setUp(cls):
            fiveconfigure.debug_mode = True
            zcml.load_config('configure.zcml',
                             collective.atimage.transformtoolbar)
            fiveconfigure.debug_mode = False

        @classmethod
        def tearDown(cls):
            pass


def test_suite():
    return unittest.TestSuite([

        # Unit tests
        #doctestunit.DocFileSuite(
        #    'README.txt', package='collective.atimage.transformtoolbar',
        #    setUp=testing.setUp, tearDown=testing.tearDown),

        #doctestunit.DocTestSuite(
        #    module='collective.atimage.transformtoolbar.mymodule',
        #    setUp=testing.setUp, tearDown=testing.tearDown),


        # Integration tests that use PloneTestCase
        ztc.ZopeDocFileSuite(
            'README.txt', package='collective.atimage.transformtoolbar',
            test_class=base.FunctionalTestCaseWithContent),

        #ztc.FunctionalDocFileSuite(
        #    'browser.txt', package='collective.atimage.transformtoolbar',
        #    test_class=TestCase),

        ])

if __name__ == '__main__':
    unittest.main(defaultTest='test_suite')
